@@ -7,52 +7,6 @@ from univer_db.orm import get_base
 Base = get_base()
 
 
-class Faculty(Base):
-    """
-    Модель "Факультет"
-    """
-
-    __tablename__ = 'univer_faculty'
-
-    id = Column('faculty_id', Integer, primary_key=True)
-    status = Column(Integer)
-    name_kz = Column('faculty_name_kz', String(200))
-    name_ru = Column('faculty_name_ru', String(200))
-    name_en = Column('faculty_name_en', String(200))
-
-    def __repr__(self):
-        return "<Faculty {}>".format(self)
-    
-    def __str__(self):
-        return self.name_ru
-
-
-class EnrollmentType(Base):
-    """
-    Модель "Тип поступления"
-    Статус: Выполняется
-    """
-
-    __tablename__ = 'univer_enrollment_type'
-
-    # Идентификатор
-    id = Column('enrollment_type_id', Integer, primary_key=True)
-
-    # Наименование
-    name_ru = Column('enrollment_type_name_ru', String(100))
-    name_kz = Column('enrollment_type_name_kz', String(100))
-    name_en = Column('enrollment_type_name_en', String(100))
-
-    # Статус
-    status = Column(Integer)
-
-    def __repr__(self):
-        return '<EnrollmentType {} (id={} status={})>'.format(self, self.id, self.status)
-    
-    def __str__(self):
-        return self.name_ru
-
-
 class Speciality(Base):
     """
     Модель "Специальность"
@@ -85,69 +39,6 @@ class Speciality(Base):
         return "{} - {}".format(self.code, self.name_ru)
 
 
-class StructureDivision(Base):
-    """
-    Модель "Подразделение"
-    """
-
-    __tablename__ = 'univer_structure_division_1c'
-
-    id = Column('structure_division_id', Integer, primary_key=True)
-    name_kz = Column('structure_division_name_kz', String(500))
-    name_ru = Column('structure_division_name_ru', String(500))
-    name_en = Column('structure_division_name_en', String(500))
-    status = Column(Integer)
-
-    def __repr__(self):
-        return '<StructureDivision {}>'.format(self)
-    
-    def __str__(self):
-        return self.name_ru
-
-
-class PersonnelStructureDivisionLink(Base):
-    """
-    Модель "Ссылка персонала с подразделением"
-    """
-
-    __tablename__ = 'univer_personal_struct_pos_link_1c'
-
-    id = Column('pers_struct_pos_link_id', Integer, primary_key=True)
-    status = Column(Integer)
-    personnel_id = Column('personal_id', ForeignKey('univer_personal.personal_id'))
-    personnel = relationship('Personnel')
-    structure_division_id = Column(ForeignKey('univer_structure_division_1c.structure_division_id'))
-    structure_division = relationship('StructureDivision')
-
-    def __repr__(self):
-        return '<PersonnelStructureDivisionLink {}>'.format(self)
-    
-    def __str__(self):
-        return '{} ({})'.format(self.personnel, self.structure_division)
-
-
-class Chair(Base):
-    """
-    Модель "Кафедра"
-    """
-
-    __tablename__ = 'univer_chair'
-
-    id = Column('chair_id', Integer, primary_key=True)
-    status = Column(Integer)
-    name_kz = Column('chair_name_kz', String(200))
-    name_ru = Column('chair_name_ru', String(200))
-    name_en = Column('chair_name_en', String(200))
-    structure_division_id = Column(ForeignKey('univer_structure_division_1c.structure_division_id'))
-    structure_division = relationship('StructureDivision')
-
-    def __repr__(self):
-        return '<Chair {}>'.format(self)
-    
-    def __str__(self):
-        return self.name_ru
-
-
 class SpecialityChair(Base):
     """
     Модель отношений "Специальность-Кафедра"
@@ -609,84 +500,4 @@ class Progress(Base):
         return '<Progress {}>'.format(self)
     
     def __str__(self):
-        return '{} - {}'.format(self.student, self.subject)
-
-
-class Sheet(Base):
-    """
-    Модель "Ведомость"
-    """
-
-    __tablename__ = 'univer_sheet'
-
-    # Идентификатор
-    id = Column('sheet_id', Integer, primary_key=True)
-
-    # Тип ведомости
-    sheet_type_id = Column(ForeignKey('univer_sheet_type.sheet_type_id'))
-    sheet_type = relationship('SheetType')
-
-    # Группа
-    group_id = Column(ForeignKey('univer_group.group_id'))
-    group = relationship('Group')
-
-    def __repr__(self):
-        return '<Sheet {}>'.format(self)
-    
-    def __str__(self):
-        return str(self.id)
-
-
-class SheetType(Base):
-    """
-    Модель "Тип ведомости"
-    """
-
-    __tablename__ = 'univer_sheet_type'
-
-    # Идентификатор
-    id = Column('sheet_type_id', Integer, primary_key=True)
-
-    # Наименование
-    name_ru = Column('sheet_type_name_ru', String(200))
-
-    # Статус
-    status = Column(Integer)
-
-    def __repr__(self):
-        return '<SheetType {} (id={} status={})>'.format(self, self.id, self.status)
-    
-    def __str__(self):
-        return self.name_ru
-
-
-class SheetResult(Base):
-    """
-    Модель "Результаты ведомости"
-    """
-
-    __tablename__ = 'univer_sheet_result'
-
-    sheet_id = Column(ForeignKey('univer_sheet.sheet_id'), primary_key=True)
-    sheet = relationship('Sheet')
-    subject_id = Column(ForeignKey('univer_subject.subject_id'))
-    subject = relationship('Subject')
-    teacher_id = Column(ForeignKey('univer_teacher.teacher_id'))
-    teacher = relationship('Teacher')
-    academ_year = Column(Integer)
-    semester = Column('semestr', Integer)
-    control = Column(Integer, primary_key=True)
-    student_id = Column(ForeignKey('univer_students.students_id'), primary_key=True)
-    student = relationship('Student')
-    result = Column(Float)
-    date_keep = Column(DateTime)
-    P_P = Column(Integer)
-    n_seme = Column(Integer)
-    mark_sheet_result = Column(Integer)
-    retake_type = Column(Integer)
-
-    def __repr__(self):
-        return '<SheetResult {} (sheet_id={})>'.format(self, self.sheet_id)
-    
-    def __str__(self):
-        return str(self.sheet_id)
\ No newline at end of file
+        return '{} - {}'.format(self.student, self.subject)
\ No newline at end of file
